@@ -13,7 +13,7 @@ BEGIN {
         require Win32;
     }
 }
-our $VERSION = '1.35';
+our $VERSION = '1.63';
 
 sub ANY_PORT            { return 0 }
 sub _GETPWUID_DIR_INDEX { return 7 }
@@ -225,10 +225,16 @@ sub new {
     $profile->set_value( 'marionette.port',                       ANY_PORT() );
     $profile->set_value( 'network.http.prompt-temp-redirect',     'false', 0 );
     $profile->set_value( 'network.http.request.max-start-delay',  '0',     0 );
+    $profile->set_value( 'network.proxy.socks_remote_dns',        'true',  0 );
     $profile->set_value( 'security.osclientcerts.autoload',       'true',  0 );
-    $profile->set_value( 'signon.autofillForms',                  'false', 0 );
-    $profile->set_value( 'signon.rememberSignons',                'false', 0 );
-    $profile->set_value( 'startup.homepage_welcome_url', 'about:blank',    1 );
+    $profile->set_value( 'security.webauth.webauthn_enable_usbtoken',
+        'false', 0 );
+    $profile->set_value( 'security.webauth.webauthn_enable_softtoken',
+        'true', 0 );
+    $profile->set_value( 'signon.autofillForms',         'false',       0 );
+    $profile->set_value( 'signon.autologin.proxy',       'true',        0 );
+    $profile->set_value( 'signon.rememberSignons',       'false',       0 );
+    $profile->set_value( 'startup.homepage_welcome_url', 'about:blank', 1 );
     $profile->set_value( 'startup.homepage_welcome_url.additional',
         'about:blank', 1 );
 
@@ -253,7 +259,7 @@ sub new {
             time, 0 );
         $profile->set_value( 'app.update.staging.enabled', 'false',      0 );
         $profile->set_value( 'app.update.timer',           '131400000',  0 );
-        $profile->set_value( 'beacon.enabled',             'false',      0 );
+        $profile->set_value( 'beacon.enabled',             'true',       0 );
         $profile->set_value( 'browser.aboutConfig.showWarning', 'false', 0 );
         $profile->set_value( 'browser.aboutHomeSnippets.updateUrl', q[], 1 );
         $profile->set_value( 'browser.beacon.enabled',          'false', 0 );
@@ -345,6 +351,8 @@ sub new {
         $profile->set_value( 'media.navigator.enabled',    'false', 0 );
         $profile->set_value( 'network.captive-portal-service.enabled',
             'false', 0 );
+        $profile->set_value( 'network.connectivity-service.enabled',
+            'false', 0 );
         $profile->set_value( 'network.cookie.lifetimePolicy',       '2',    0 );
         $profile->set_value( 'privacy.clearOnShutdown.downloads',   'true', 0 );
         $profile->set_value( 'privacy.clearOnShutdown.formdata',    'true', 0 );
@@ -354,7 +362,10 @@ sub new {
         $profile->set_value( 'privacy.clearOnShutdown.sessions',    'true', 0 );
         $profile->set_value( 'privacy.clearOnShutdown.siteSettings', 'true',
             0 );
-        $profile->set_value( 'privacy.donottrackheader.enabled',   'true', 0 );
+        $profile->set_value( 'privacy.donottrackheader.enabled', 'true', 0 );
+        $profile->set_value( 'privacy.fingerprintingProtection', 'true', 0 );
+        $profile->set_value( 'privacy.fingerprintingProtection.pbmode',
+            'true', 0 );
         $profile->set_value( 'privacy.trackingprotection.enabled', 'true', 0 );
         $profile->set_value(
             'privacy.trackingprotection.fingerprinting.enabled',
@@ -521,7 +532,7 @@ Firefox::Marionette::Profile - Represents a prefs.js Firefox Profile
 
 =head1 VERSION
 
-Version 1.35
+Version 1.63
 
 =head1 SYNOPSIS
 
@@ -552,12 +563,14 @@ Version 1.35
 
 This module handles the implementation of a C<prefs.js> Firefox Profile
 
-=head1 SUBROUTINES/METHODS
+=head1 CONSTANTS
 
 =head2 ANY_PORT
 
 returns the port number for Firefox to listen on any port (0).
 
+=head1 SUBROUTINES/METHODS
+
 =head2 new
 
 returns a new L<profile|Firefox::Marionette::Profile>.
@@ -681,7 +694,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
